@@ -9,7 +9,7 @@ import defusedxml.ElementTree as ET
 
 from pydelica.exception import UnknownOptionError, UnknownLibraryError
 
-from typing import Any, List, Dict
+from typing import Any, Iterable, List
 
 
 class Solver(enum.Enum):
@@ -19,8 +19,17 @@ class Solver(enum.Enum):
 
 
 class LibrarySetup:
-    def __init__(self, library_folder: str = None):
+    """Object containing setup for a particular Modelica library version"""
+    def __init__(self, library_folder: str = None) -> None:
+        """Create a setup object
+
+        Parameters
+        ----------
+        library_folder : str, optional
+            specify location of the Modelica libraries, else use system defaults
+        """
         self._logger = logging.getLogger("PyDelica.LibrarySetup")
+
         # Disable environment setting on Windows as it does not work at present
         if platform.system() != "Windows":
             self._libraries = self._get_library_folders(library_folder)
@@ -113,7 +122,26 @@ class LibrarySetup:
 
 
 class SimulationOptions(collections.abc.MutableMapping):
+    """
+    Simulation Options
+    ------------------
+
+    Object contains configuration settings for simulation within Modelica
+    """
     def __init__(self, xml_model_file: str) -> None:
+        """Create a configuration object from a given model XML file
+
+        Parameters
+        ----------
+        xml_model_file : str
+            file containing the parameters and configurations from a model
+            after compilation
+
+        Raises
+        ------
+        FileNotFoundError
+            if the specified XML file does not exist
+        """
         self._model_xml = xml_model_file
 
         if not os.path.exists(xml_model_file):
@@ -127,7 +155,7 @@ class SimulationOptions(collections.abc.MutableMapping):
 
         self._opts = list(_xml_obj.iterfind("DefaultExperiment"))[0].attrib
 
-    def _write_opts(self):
+    def _write_opts(self) -> None:
         _xml_obj = ET.parse(self._model_xml)
 
         for opt in _xml_obj.findall("DefaultExperiment")[0].attrib:
@@ -148,6 +176,20 @@ class SimulationOptions(collections.abc.MutableMapping):
         del self._opts[key]
 
     def set_option(self, option_name: str, value: Any) -> None:
+        """Set the value of an option
+
+        Parameters
+        ----------
+        option_name : str
+            name of option to update
+        value : Any
+            new value for option
+
+        Raises
+        ------
+        UnknownOptionError
+            if the option does not exist
+        """
         if option_name not in self._opts:
             raise UnknownOptionError(option_name)
         _opt = [
@@ -156,8 +198,8 @@ class SimulationOptions(collections.abc.MutableMapping):
         self._opts[_opt] = value
         self._write_opts()
 
-    def __len__(self):
+    def __len__(self) -> int:
         return len(self._opts)
 
-    def __iter__(self):
+    def __iter__(self) -> Iterable:
         return iter(self._opts)
